@@ -15,8 +15,7 @@ from reV.handlers.outputs import Outputs
 from reV.SAM.econ import LCOE as SAM_LCOE
 from reV.SAM.econ import SingleOwner
 from reV.SAM.windbos import WindBos
-from reV.utilities.exceptions import (OutputWarning, ExecutionError,
-                                      OffshoreWindInputWarning)
+from reV.utilities.exceptions import ExecutionError, OffshoreWindInputWarning
 
 from rex.resource import Resource
 from rex.multi_file_resource import MultiFileResource
@@ -130,8 +129,8 @@ class Econ(Gen):
         self._sam_obj_default = None
         self.mem_util_lim = mem_util_lim
 
-        self._output_request = self._parse_output_request(output_request)
         self._site_data = self._parse_site_data(site_data)
+        self._output_request = self._parse_output_request(output_request)
 
         self._run_attrs = {'points_control': str(points_control),
                            'cf_file': cf_file,
@@ -147,7 +146,6 @@ class Econ(Gen):
         self._finished_sites = []
         self._out_n_sites = 0
         self._out_chunk = ()
-        self._init_out_arrays()
 
         # initialize output file or append econ data to gen file
         if append:
@@ -157,6 +155,7 @@ class Econ(Gen):
 
         mode = 'a' if append else 'w'
         self._init_h5(mode=mode)
+        self._init_out_arrays()
 
     @property
     def cf_file(self):
@@ -169,6 +168,17 @@ class Econ(Gen):
         """
         return self._cf_file
 
+    @property
+    def cf_year(self):
+        """Get the analysis year.
+
+        Returns
+        -------
+        cf_year : int | str
+            reV generation year to analyze.
+        """
+        return self._year
+
     @property
     def site_data(self):
         """Get the site-specific dataframe.
@@ -377,8 +387,7 @@ class Econ(Gen):
             if request not in self.OUT_ATTRS:
                 msg = ('User output request "{}" not recognized. '
                        'Will attempt to extract from PySAM.'.format(request))
-                logger.warning(msg)
-                warn(msg, OutputWarning)
+                logger.debug(msg)
 
         modules = []
         for request in output_request:
@@ -473,6 +482,41 @@ class Econ(Gen):
         self.project_points.join_df(self.site_data,
                                     key=self.site_data.index.name)
 
+    def _get_data_shape(self, dset, n_sites):
+        """Get the output array shape based on OUT_ATTRS or PySAM.Outputs.
+
+        This Econ get data shape method will also first check for the dset in
+        the site_data table. If not found in site_data, the dataset will be
+        looked for in OUT_ATTRS and PySAM.Outputs as it would for Generation.
+
+        Parameters
+        ----------
+        dset : str
+            Variable name to get shape for.
+        n_sites : int
+            Number of sites for this data shape.
+
+        Returns
+        -------
+        shape : tuple
+            1D or 2D shape tuple for dset.
+        """
+
+        if dset in self.site_data:
+            data_shape = (n_sites, )
+            data = self.site_data[dset].values[0]
+
+            if isinstance(data, (list, tuple, np.ndarray, str)):
+                msg = ('Cannot pass through non-scalar site_data '
+                       'input key "{}" as an output_request!'.format(dset))
+                logger.error(msg)
+                raise ExecutionError(msg)
+
+        else:
+            data_shape = super()._get_data_shape(dset, n_sites)
+
+        return data_shape
+
     @classmethod
     def reV_run(cls, points, sam_files, cf_file,
                 cf_year=None, site_data=None, output_request=('lcoe_fcr',),
@@ -552,9 +596,9 @@ class Econ(Gen):
                             .format(econ.cf_file, diff))
 
         # make a kwarg dict
-        kwargs = {'output_request': output_request,
-                  'cf_file': cf_file,
-                  'cf_year': cf_year}
+        kwargs = {'output_request': econ.output_request,
+                  'cf_file': econ.cf_file,
+                  'cf_year': econ.cf_year}
 
         # add site_df to project points dataframe
         econ.add_site_data_to_pp()
