@@ -270,7 +270,6 @@ class Gen:
                            'sam_module': self._sam_module.MODULE}
 
         self._output_request = self._parse_output_request(output_request)
-
         self._multi_h5_res, self._hsds = check_res_file(res_file)
 
         if self.tech not in self.OPTIONS:
@@ -286,12 +285,12 @@ class Gen:
         self._finished_sites = []
         self._out_n_sites = 0
         self._out_chunk = ()
-        self._init_out_arrays()
         self._check_sam_version_inputs()
 
         # initialize output file
         self._init_fpath()
         self._init_h5()
+        self._init_out_arrays()
 
     @property
     def output_request(self):
@@ -1017,8 +1016,7 @@ class Gen:
             if request not in self.OUT_ATTRS:
                 msg = ('User output request "{}" not recognized. '
                        'Will attempt to extract from PySAM.'.format(request))
-                logger.warning(msg)
-                warn(msg, OutputWarning)
+                logger.debug(msg)
 
         return list(set(output_request))
 
@@ -1044,6 +1042,15 @@ class Gen:
             else:
                 data_shape = (n_sites, )
 
+        elif dset in self.project_points.all_sam_input_keys:
+            data_shape = (n_sites, )
+            data = list(self.project_points.sam_configs.values())[0][dset]
+            if isinstance(data, (list, tuple, np.ndarray, str)):
+                msg = ('Cannot pass through non-scalar SAM input key "{}" '
+                       'as an output_request!'.format(dset))
+                logger.error(msg)
+                raise ExecutionError(msg)
+
         else:
             if self._sam_obj_default is None:
                 init_obj = self._sam_module()
@@ -1178,7 +1185,6 @@ class Gen:
                 dtype = self.OUT_ATTRS[request].get('dtype', 'float32')
 
             shape = self._get_data_shape(request, self._out_n_sites)
-
             # initialize the output request as an array of zeros
             self._out[request] = np.zeros(shape, dtype=dtype)
 
@@ -1283,14 +1289,13 @@ class Gen:
             with Outputs(self._fpath, mode='a') as f:
 
                 # iterate through all output requests writing each as a dataset
-                for dset in self.output_request:
-
-                    if len(self._out[dset].shape) == 1:
+                for dset, arr in self._out.items():
+                    if len(arr.shape) == 1:
                         # write array of scalars
-                        f[dset, islice] = self._out[dset]
+                        f[dset, islice] = arr
                     else:
                         # write 2D array of profiles
-                        f[dset, :, islice] = self._out[dset]
+                        f[dset, :, islice] = arr
 
             logger.debug('Flushed generation output successfully to disk.')
 
